@@ -109,7 +109,7 @@ class Newton:
             return res.text
 
     def export_tasks(self, project_id: str=None):
-        api_url = f"{self.api_base}/project/list/{project_id}"
+        api_url = f"{self.api_base}/task/export/{project_id}"
 
         res = requests.get(api_url, headers=self.__headers)
         if res.ok:
@@ -117,7 +117,7 @@ class Newton:
         else:
             return res.text
  
-    def add_project(self, body: dict):
+    def create_project(self, body: dict):
         api_url = f"{self.api_base}/project"
 
         # request_body = self.__create_body(**body)
